# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-08-02 20:54
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shorty', '0003_auto_20160602_1131'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shorturl',
            name='external',
            field=models.BooleanField(default=False, help_text=b"Should this short link be available outside the company's network?"),
        ),
        migrations.AlterField(
            model_name='shorturl',
            name='redirect',
            field=models.TextField(validators=[django.core.validators.URLValidator()]),
        ),
    ]
