# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-06-02 11:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shorty', '0002_auto_20160322_1720'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shorturl',
            options={'ordering': ('-created',), 'verbose_name': 'Short URL', 'verbose_name_plural': 'Short URLs'},
        ),
        migrations.AddField(
            model_name='shorturl',
            name='external',
            field=models.BooleanField(default=False, help_text=b'Available externally'),
        ),
        migrations.AlterField(
            model_name='shorturl',
            name='path',
            field=models.SlugField(error_messages={b'unique': b'This short URL is already in use; please choose something different, or leave blank for a random URL'}, unique=True),
        ),
    ]
